/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.pig4cloud.plugin.excel.annotation.RequestExcel;
import com.pig4cloud.plugin.excel.vo.ErrorMessage;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmpEducation;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmpEducationService;
import com.yifu.cloud.plus.v1.yifu.archives.vo.EmpEducationExcelVO;
import com.yifu.cloud.plus.v1.yifu.archives.vo.EmpEducationUpdateExcelVo;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.CommonConstants;
import com.yifu.cloud.plus.v1.yifu.common.core.util.Common;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 员工学历信息表
 *
 * @author fxj
 * @date 2022-06-18 09:39:46
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tempeducation" )
@Tag(name = "员工学历信息表管理")
public class TEmpEducationController {

    private final TEmpEducationService tEmpEducationService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param tEmpEducation 员工学历信息表
     * @return
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page" )
    @PreAuthorize("@pms.hasPermission('archives_tempeducation_get')" )
    public R<IPage<TEmpEducation>> getTEmpEducationPage(Page page, TEmpEducation tEmpEducation) {
        return R.ok(tEmpEducationService.page(page, Wrappers.query(tEmpEducation)));
    }


    /**
     * 通过id查询员工学历信息表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_tempeducation_get')" )
    public R<TEmpEducation> getById(@PathVariable("id" ) Long id) {
        return R.ok(tEmpEducationService.getById(id));
    }

    /**
     * 新增员工学历信息表
     * @param tEmpEducation 员工学历信息表
     * @return R
     */
    @Operation(summary = "新增员工学历信息表", description = "新增员工学历信息表")
    @SysLog("新增员工学历信息表" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('archives_tempeducation_add')" )
    public R<Boolean> save(@RequestBody TEmpEducation tEmpEducation) {
        return tEmpEducationService.saveDiy(tEmpEducation);
    }

    /**
     * 修改员工学历信息表
     * @param tEmpEducation 员工学历信息表
     * @return R
     */
    @Operation(summary = "修改员工学历信息表", description = "修改员工学历信息表")
    @SysLog("修改员工学历信息表" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('archives_tempeducation_edit')" )
    public R<Boolean> updateById(@RequestBody TEmpEducation tEmpEducation) {
        return tEmpEducationService.updateByIdDiy(tEmpEducation);
    }

    /**
     * 通过id删除员工学历信息表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除员工学历信息表", description = "通过id删除员工学历信息表")
    @SysLog("通过id删除员工学历信息表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_tempeducation_del')" )
    public R<Boolean> removeById(@PathVariable Long id) {
        return R.ok(tEmpEducationService.removeById(id));
    }

	/**
	 * 通过id删除员工学历信息表
	 * @param ids
	 * @return R
	 */
	@Operation(summary = "通过id删除员工学历信息表", description = "通过id删除员工学历息表 @pms.hasPermission('archives_education_del_batch')")
	@SysLog("通过id删除员工学历信息表" )
	@DeleteMapping("/removeByIds" )
	@PreAuthorize("@pms.hasPermission('archives_education_del_batch')" )
	public R<Boolean> removeByIds(String ids) {
		List<String> idList = null;
		if (Common.isNotNull(ids)){
			idList = Common.initStrToList(ids, CommonConstants.COMMA_STRING);
		}
		return R.ok(tEmpEducationService.removeByIds(idList));
	}

	/**
	 * 批量新增员工学历信息
	 *
	 * @param excelVOList
	 * @return
	 * @Author fxj
	 * @Date 2019-08-16
	 **/
	@Operation(description = "批量新增员工学历信息 hasPermission('archives_education_importListAdd')")
	@SysLog("批量新增员工学历信息")
	@PostMapping("/importListAdd")
	@PreAuthorize("@pms.hasPermission('archives_education_importListAdd')")
	public R<List<ErrorMessage>> importListAdd(@RequestExcel List<EmpEducationExcelVO> excelVOList, BindingResult bindingResult) {
		return tEmpEducationService.importEmpEducation(excelVOList, bindingResult);
	}

	/**
	 * 批量更新员工学历信息
	 *
	 * @param excelVOList
	 * @return
	 * @Author fxj
	 * @Date 2019-08-16
	 **/
	@Operation(description = "批量更新员工学历信息 hasPermission('archives_education_importListUpdate')")
	@SysLog("批量更新员工学历信息")
	@PostMapping("/importListUpate")
	@PreAuthorize("@pms.hasPermission('archives_education_importListUpdate')")
	public R<List<ErrorMessage>> importListUpate(@RequestExcel List<EmpEducationUpdateExcelVo> excelVOList, BindingResult bindingResult) {
		return tEmpEducationService.importEmpEducationUpdate(excelVOList, bindingResult);
	}
}
