/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmployeeProject;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmployeeProjectService;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * 项目档案表
 *
 * @author huyc
 * @date 2022-06-20 09:19:40
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/temployeeproject" )
@Tag(name = "项目档案表管理")
public class TEmployeeProjectController {

    private final TEmployeeProjectService tEmployeeProjectService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param tEmployeeProject 项目档案表
     * @return
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page" )
    @PreAuthorize("@pms.hasPermission('archives_temployeeproject_get')" )
    public R getTEmployeeProjectPage(Page page, TEmployeeProject tEmployeeProject) {
        return R.ok(tEmployeeProjectService.page(page, Wrappers.query(tEmployeeProject)));
    }


    /**
     * 通过id查询项目档案表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_temployeeproject_get')" )
    public R getById(@PathVariable("id" ) String id) {
        return R.ok(tEmployeeProjectService.getById(id));
    }

    /**
     * 新增项目档案表
     * @param tEmployeeProject 项目档案表
     * @return R
     */
    @Operation(summary = "新增项目档案表", description = "新增项目档案表")
    @SysLog("新增项目档案表" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('archives_temployeeproject_add')" )
    public R save(@RequestBody TEmployeeProject tEmployeeProject) {
        return R.ok(tEmployeeProjectService.save(tEmployeeProject));
    }

    /**
     * 修改项目档案表
     * @param tEmployeeProject 项目档案表
     * @return R
     */
    @Operation(summary = "修改项目档案表", description = "修改项目档案表")
    @SysLog("修改项目档案表" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('archives_temployeeproject_edit')" )
    public R updateById(@RequestBody TEmployeeProject tEmployeeProject) {
        return R.ok(tEmployeeProjectService.updateById(tEmployeeProject));
    }

    /**
     * 通过id删除项目档案表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除项目档案表", description = "通过id删除项目档案表")
    @SysLog("通过id删除项目档案表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_temployeeproject_del')" )
    public R removeById(@PathVariable String id) {
        return R.ok(tEmployeeProjectService.removeById(id));
    }

	/**
	 * 新增项目档案校验
	 * @param tEmployeeProject 项目档案表
	 * @return R
	 */
	@Operation(summary = "新增项目档案校验", description = "新增项目档案校验")
	@SysLog("新增项目档案校验" )
	@PostMapping("/check")
	@PreAuthorize("@pms.hasPermission('archives_temployeeproject_addcheck')" )
	public R addCheck(@RequestBody TEmployeeProject tEmployeeProject) {
		return R.ok(tEmployeeProjectService.addCheck(tEmployeeProject));
	}
}
